==> drupal-8.1.0-rc1.tar.gz: drupal-8.1.0-rc1/core/modules/field/tests/src/Kernel/FormatterPluginManagerTest.php <==
<?php

/**
 * @file
 * Contains \Drupal\Tests\field\Kernel\FormatterPluginManagerTest.
 */

namespace Drupal\Tests\field\Kernel;

use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Tests the field formatter plugin manager.
 *
 * @group field
 */
class FormatterPluginManagerTest extends FieldKernelTestBase {

  /**
   * Tests that getInstance falls back on default if current is not applicable.
   *
   * @see \Drupal\field\Tests\WidgetPluginManagerTest::testNotApplicableFallback()
   */
  public function testNotApplicableFallback() {
    /** @var \Drupal\Core\Field\FormatterPluginManager $formatter_plugin_manager */
    $formatter_plugin_manager = \Drupal::service('plugin.manager.field.formatter');

    $base_field_definition = BaseFieldDefinition::create('test_field')
      // Set a name that will make isApplicable() return TRUE.
      ->setName('field_test_field');

    $formatter_options = array(
      'field_definition' => $base_field_definition,
      'view_mode' => 'default',
      'configuration' => array(
        'type' => 'field_test_applicable',
      ),
    );

    $instance = $formatter_plugin_manager->getInstance($formatter_options);
    $this->assertEqual($instance->getPluginId(), 'field_test_applicable');

    // Now set name to something that makes isApplicable() return FALSE.
    $base_field_definition->setName('deny_applicable');
    $instance = $formatter_plugin_manager->getInstance($formatter_options);

    // Instance should be default widget.
    $this->assertNotEqual($instance->getPluginId(), 'field_test_applicable');
    $this->assertEqual($instance->getPluginId(), 'field_test_default');
  }

}

==> drupal-9.1.8.tar.gz: drupal-9.1.8/core/modules/field/tests/src/Kernel/FormatterPluginManagerTest.php <==
<?php

namespace Drupal\Tests\field\Kernel;

use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Tests the field formatter plugin manager.
 *
 * @group field
 */
class FormatterPluginManagerTest extends FieldKernelTestBase {

  /**
   * Tests that getInstance falls back on default if current is not applicable.
   *
   * @see \Drupal\field\Tests\WidgetPluginManagerTest::testNotApplicableFallback()
   */
  public function testNotApplicableFallback() {
    /** @var \Drupal\Core\Field\FormatterPluginManager $formatter_plugin_manager */
    $formatter_plugin_manager = \Drupal::service('plugin.manager.field.formatter');

    $base_field_definition = BaseFieldDefinition::create('test_field')
      // Set a name that will make isApplicable() return TRUE.
      ->setName('field_test_field');

    $formatter_options = [
      'field_definition' => $base_field_definition,
      'view_mode' => 'default',
      'configuration' => [
        'type' => 'field_test_applicable',
      ],
    ];

    $instance = $formatter_plugin_manager->getInstance($formatter_options);
    $this->assertEqual('field_test_applicable', $instance->getPluginId());

    // Now set name to something that makes isApplicable() return FALSE.
    $base_field_definition->setName('deny_applicable');
    $instance = $formatter_plugin_manager->getInstance($formatter_options);

    // Instance should be default widget.
    $this->assertNotSame('field_test_applicable', $instance->getPluginId());
    $this->assertEqual('field_test_default', $instance->getPluginId());
  }

}
